Tooltip Visual Test: Default

- Anchor 1
- Anchor 2
- Anchor 3
- Anchor 4
- Anchor 5
- Anchor 6

collision detection should kick in around here
I'm a link to a footnote. I'm another link to a footnote.
right aligned with custom position
gets its content via ajax
gets its content via ajax, caches the response
span
div nested span
Text in bold.
First Name:
Last Name:
This is the footnote, including other elements
This is the other footnote, including other elements